"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DtoBillingPeriodInfoTypedDict(TypedDict):
    end_time: NotRequired[str]
    period: NotRequired[str]
    r"""e.g., \"monthly\", \"yearly\" """
    start_time: NotRequired[str]


class DtoBillingPeriodInfo(BaseModel):
    end_time: Optional[str] = None

    period: Optional[str] = None
    r"""e.g., \"monthly\", \"yearly\" """

    start_time: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["end_time", "period", "start_time"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from flexprice_py.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetInvoiceRequestTypedDict(TypedDict):
    id: str
    r"""Invoice ID"""
    expand_by_source: NotRequired[bool]
    r"""Include source-level price breakdown for usage line items (legacy)"""
    group_by: NotRequired[List[str]]
    r"""Group usage breakdown by specified fields (e.g., source, feature_id, properties.org_id)"""


class GetInvoiceRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Invoice ID"""

    expand_by_source: Annotated[
        Optional[bool],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""Include source-level price breakdown for usage line items (legacy)"""

    group_by: Annotated[
        Optional[List[str]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""Group usage breakdown by specified fields (e.g., source, feature_id, properties.org_id)"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["expand_by_source", "group_by"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DtoCustomAnalyticItemTypedDict(TypedDict):
    feature_name: NotRequired[str]
    r"""Name of the feature this applies to"""
    id: NotRequired[str]
    name: NotRequired[str]
    r"""Calculation name (e.g., \"Revenue per Minute\")"""
    type: NotRequired[str]
    r"""\"feature\", \"meter\", \"event_name\" """
    value: NotRequired[str]


class DtoCustomAnalyticItem(BaseModel):
    feature_name: Optional[str] = None
    r"""Name of the feature this applies to"""

    id: Optional[str] = None

    name: Optional[str] = None
    r"""Calculation name (e.g., \"Revenue per Minute\")"""

    type: Optional[str] = None
    r"""\"feature\", \"meter\", \"event_name\" """

    value: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["feature_name", "id", "name", "type", "value"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_tenantbillingdetails import (
    DtoTenantBillingDetails,
    DtoTenantBillingDetailsTypedDict,
)
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class DtoTenantResponseTypedDict(TypedDict):
    billing_details: NotRequired[DtoTenantBillingDetailsTypedDict]
    created_at: NotRequired[str]
    id: NotRequired[str]
    metadata: NotRequired[Dict[str, str]]
    name: NotRequired[str]
    status: NotRequired[str]
    updated_at: NotRequired[str]


class DtoTenantResponse(BaseModel):
    billing_details: Optional[DtoTenantBillingDetails] = None

    created_at: Optional[str] = None

    id: Optional[str] = None

    metadata: Optional[Dict[str, str]] = None

    name: Optional[str] = None

    status: Optional[str] = None

    updated_at: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "billing_details",
                "created_at",
                "id",
                "metadata",
                "name",
                "status",
                "updated_at",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel
from flexprice_py.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class ListSubscriptionSchedulesRequestTypedDict(TypedDict):
    subscription_id: str
    r"""Subscription ID"""


class ListSubscriptionSchedulesRequest(BaseModel):
    subscription_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Subscription ID"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.models.components import (
    dto_updatetaxraterequest as components_dto_updatetaxraterequest,
)
from flexprice_py.types import BaseModel
from flexprice_py.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateTaxRateRequestTypedDict(TypedDict):
    id: str
    r"""Tax rate ID"""
    body: components_dto_updatetaxraterequest.DtoUpdateTaxRateRequestTypedDict
    r"""Tax rate to update"""


class UpdateTaxRateRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Tax rate ID"""

    body: Annotated[
        components_dto_updatetaxraterequest.DtoUpdateTaxRateRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""Tax rate to update"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_customerusagesummaryresponse import (
    DtoCustomerUsageSummaryResponse,
    DtoCustomerUsageSummaryResponseTypedDict,
)
from .dto_subscriptionresponse import (
    DtoSubscriptionResponse,
    DtoSubscriptionResponseTypedDict,
)
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class DtoTenantBillingUsageTypedDict(TypedDict):
    subscriptions: NotRequired[List[DtoSubscriptionResponseTypedDict]]
    usage: NotRequired[DtoCustomerUsageSummaryResponseTypedDict]


class DtoTenantBillingUsage(BaseModel):
    subscriptions: Optional[List[DtoSubscriptionResponse]] = None

    usage: Optional[DtoCustomerUsageSummaryResponse] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["subscriptions", "usage"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DtoEnvironmentResponseTypedDict(TypedDict):
    created_at: NotRequired[str]
    id: NotRequired[str]
    name: NotRequired[str]
    type: NotRequired[str]
    updated_at: NotRequired[str]


class DtoEnvironmentResponse(BaseModel):
    created_at: Optional[str] = None

    id: Optional[str] = None

    name: Optional[str] = None

    type: Optional[str] = None

    updated_at: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["created_at", "id", "name", "type", "updated_at"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from flexprice_py.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetSubscriptionEntitlementsRequestTypedDict(TypedDict):
    id: str
    r"""Subscription ID"""
    feature_ids: NotRequired[List[str]]
    r"""Feature IDs to filter by"""


class GetSubscriptionEntitlementsRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Subscription ID"""

    feature_ids: Annotated[
        Optional[List[str]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""Feature IDs to filter by"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["feature_ids"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
